==> bruno-1.0.0.tar.gz: lib/src/constants/brn_asset_constants.dart <==
class BrnAsset {


  static const String emptyState = "images/empty_state.png";
  static const String stepTitle = 'images/img_step_title.png';

  static const String refreshArrowUp = "images/refresh_arrow_up.png";
  static const String refreshArrowDown = "images/refresh_arrow_down.png";
  static const String iconSelectionReset = "images/icon_selection_reset.png";
  static const String iconSingleSelected = "images/icon_single_selected.png";
  static const String iconMultiSelected = "images/icon_multi_selected.png";
  static const String iconUnSelect = "images/icon_unselect.png";
  static const String iconMore = "images/icon_more.png";
  static const String iconAlert = "icons/icon_alert.png";
  static const String iconWarning ="icons/icon_warning.png";
  static const String iconSuccess = "icons/icon_success.png";

  static const String iconStarSize = "images/icon_star_size.png";
  static const String iconStarSizeSelected = "images/icon_star_size_selected.png";
  static const String iconBottomPickerRightTopBg = "images/icon_bottom_picker_right_top_bg.png";

  static const String ICON_ARROWUP_SELECT = "images/icon_arrow_up_selected.png";
  static const String ICON_REFRESH = "assets/images/icon_refresh.png";
  static const String ICON_ARROWDOWN_SELECT = "images/icon_arrow_down_selected.png";
  static const String ICON_ARROWDOWN_UNSELECT = "images/icon_arrow_down_unselected.png";
  static const String ICON_ARROW_RIGHT_1 = "icons/icon_right_arrow_1.png";
  static const String SELECT_CHECKED_STATUS = "images/select_checked_status.png";
  static const String SELECT_NORMAL_STATUS = "icons/normol_border.png";
  static const String ICON_SELECTED_UP_TRIANGLE = "icons/icon_selcted_triangle.png";
  static const String ICON_UNSELECT_DOWN_TRIANGLE = "icons/icon_unselected_triangle.png";
  static const String ICON_REQUIRE_RED = 'icons/icon_require_red.png';
  static const String ICON_RIGHT_ARROW = 'icons/icon_right_arrow.png';
  static const String ICON_BACK_WHITE = 'assets/icons/icon_back_white.png';
  static const String ICON_BACK_BLACK = 'assets/icons/icon_back_black.png';
  static const String ICON_STEP_2 = 'icons/icon_step_2.png';
  static const String ICON_STEP_3 = 'icons/icon_step_3.png';
  static const String ICON_STEP_4 = 'icons/icon_step_4.png';
  static const String ICON_STEP_5 = 'icons/icon_step_5.png';
  static const String ICON_STEP_DOING = 'icons/icon_step_doing.png';
  static const String ICON_STEP_COMPLETED = 'icons/icon_step_completed.png';

  static const String ICON_DELETE_TEXT = 'icons/ic_delete_grey.png';
  static const String ICON_SEARCH = 'icons/ic_search.png';

  static const String ICON_POPUP_CLOSE = 'icons/icon_popup_close.png';
  static const String ICON_CLOSE = 'icons/icon_close.png';
  static const String ICON_CALENDAR_PRE_MONTH = 'icons/icon_calendar_pre_month.png';
  static const String ICON_CALENDAR_NEXT_MONTH = 'icons/icon_calendar_next_month.png';

  static const String ICON_UP_ARROW = 'icons/icon_up_arrow.png';
  static const String ICON_DOWN_ARROW = 'icons/icon_down_arrow.png';
  static const String ICON_TRASH_BIN = 'icons/icon_trash.png';
  static const String ICON_STAR_UNSELECT = 'icons/icon_star_unselect.png';
  static const String ICON_STAR_SELECT = 'icons/icon_star_select.png';
  static const String ICON_ADD_FORM_ITEM = 'icons/icon_add_form_item.png';
  static const String ICON_REMOVE_FORM_ITEM = 'icons/icon_remove_form_item.png';

  static const String ICON_TRIANGLE_DOWN = 'icons/icon_triangle_down.png';
  static const String ICON_TRIANGLE_UP = 'icons/icon_triangle_up.png';

  static const String ICON_PAIR_INFO_QUESTION = 'icons/icon_pait_info_question.png';
  static const String ICON_PICKER_CLOSE = 'images/icon_guanbi.png';

  static const String ICON_NOTICE = 'icons/icon_notice.png';
  static const String ICON_NOTICE_ARROW_BLUE = 'icons/icon_notice_arrow_blue.png';
  static const String ICON_NOTICE_ARROW_GREEN = 'icons/icon_notice_arrow_green.png';
  static const String ICON_NOTICE_ARROW_ORANGE = 'icons/icon_notice_arrow_orange.png';
  static const String ICON_NOTICE_ARROW_RED = 'icons/icon_notice_arrow_red.png';
  static const String ICON_NOTICE_CLOSE_BLUE = 'icons/icon_notice_close_blue.png';
  static const String ICON_NOTICE_CLOSE_GREEN = 'icons/icon_notice_close_green.png';
  static const String ICON_NOTICE_CLOSE_ORANGE = 'icons/icon_notice_close_orange.png';
  static const String ICON_NOTICE_CLOSE_RED = 'icons/icon_notice_close_red.png';
  static const String ICON_NOTICE_FAIL = 'icons/icon_notice_fail.png';
  static const String ICON_NOTICE_RUNNING = 'icons/icon_notice_running.png';
  static const String ICON_NOTICE_SUCCEED = 'icons/icon_notice_succeed.png';
  static const String ICON_NOTICE_WARNING = 'icons/icon_notice_warning.png';

  static const String ICON_OPERATION_OTHER_RIGHT = 'icons/icon_operation_line_right.png';
  static const String ICON_OPERATION_OTHER_LEFT = 'icons/icon_operation_line_left.png';
  static const String ICON_RESULT_SUCCESS = 'icons/icon_result_success.png';
  static const String ICON_RESULT_ERROR = 'icons/icon_result_error.png';
  static const String ICON_STAR = 'icons/icon_star.png';
  static const String ICON_STAR_HALF = 'icons/icon_star_half.png';
  static const String ICON_UPARROW = 'icons/icon_uparrow.png';
  static const String ICOS_QRCODE_BG = 'assets/images/icon_qrcode_bg.png';
  static const String ICONS_QRCODE_FAILED = '/assets/images/icon_qrcode_failed.png';
  static const String ICONS_REFRESH_WHITE = 'assets/images/icon_refresh_white.png';
  static const String ICONS_AVATAR_NEW = '/assets/icons/img_avatar_new.png';

  static const String ICON_AUDIOPALYER_PLAY = 'icons/icon_audioplayer_play.png';
  static const String ICON_AUDIOPALYER_PAUSE = 'icons/icon_audioplayer_pause.png';

  static const String ICON_GREY_PLACE_HOLDER = 'icons/grey_place_holder.png';

  static const String ICON_QUOTATION_MARK = 'icons/ic_quotation_mark.png';

  static const String IMG_BACKGROUND_CARD = 'images/img_bg_card.png';

  static const String IMG_BG_BLUR = 'images/img_bg_blur.png';

  /// 用于图片右上角删除icon 的展示
  static const String ICON_DELETE = 'icons/icon_delete.png';

  static const String ICON_IM = 'images/icon_im_blue.png';
  static const String ICON_CALL = 'images/icon_call.png';
  static const String ICON_CALL_DISABLE = 'images/icon_call_disable.png';
  static const String PERSON_PLACE_HOLDER = 'packages/bruno/assets/icons/img_avatar_new.png';

  /// radio组件，用于单选和多选
  static const String ICON_RADIO_MULTI_SELECTED = 'icons/radio/multiple_selected.png';
  static const String ICON_RADIO_UNSELECTED = 'icons/radio/unselected.png';
  static const String ICON_RADIO_DISABLE_MULTI_SELECTED = 'icons/radio/disable_multi_selected.png';
  static const String ICON_RADIO_DISABLE_UNSELECTED = 'icons/radio/disable_unselected.png';
  static const String ICON_RADIO_SINGLE_SELECTED = 'icons/radio/single_selected.png';
  static const String ICON_RADIO_DISABLE_SINGLE_SELECTED =
      'icons/radio/disable_single_selected.png';

  /// 评价组件--表情
  static const String ICON_APPRAISE_BAD_UNSELECTED =
      'assets/images/icon_appraise_bad_unselected.png';
  static const String ICON_APPRAISE_NOT_GOOD_UNSELECTED =
      'assets/images/icon_appraise_not_good_unselected.png';
  static const String ICON_APPRAISE_OK_UNSELECTED = 'assets/images/icon_appraise_ok_unselected.png';
  static const String ICON_APPRAISE_GOOD_UNSELECTED =
      'assets/images/icon_appraise_good_unselected.png';
  static const String ICON_APPRAISE_SURPRISE_UNSELECTED =
      'assets/images/icon_appraise_surprise_unselected.png';

  static const String ICON_APPRAISE_BAD_DEFAULT = 'assets/images/icon_appraise_bad_default.png';
  static const String ICON_APPRAISE_NOT_GOOD_DEFAULT =
      'assets/images/icon_appraise_not_good_default.png';
  static const String ICON_APPRAISE_OK_DEFAULT = 'assets/images/icon_appraise_ok_default.png';
  static const String ICON_APPRAISE_GOOD_DEFAULT = 'assets/images/icon_appraise_good_default.png';
  static const String ICON_APPRAISE_SURPRISE_DEFAULT =
      'assets/images/icon_appraise_surprise_default.png';

  static const String ICON_APPRAISE_BAD_SELECTED = 'assets/images/icon_appraise_bad_selected.png';
  static const String ICON_APPRAISE_NOT_GOOD_SELECTED =
      'assets/images/icon_appraise_not_good_selected.png';
  static const String ICON_APPRAISE_OK_SELECTED = 'assets/images/icon_appraise_ok_selected.png';
  static const String ICON_APPRAISE_GOOD_SELECTED = 'assets/images/icon_appraise_good_selected.png';
  static const String ICON_APPRAISE_SURPRISE_SELECTED =
      'assets/images/icon_appraise_surprise_selected.png';
  static const String ICON_QUESTION = "icons/icon_question.png";

  /// 录入项icon
  static const String ICON_ADD_DISABLE = "icons/icon_add_disable.png";
  static const String ICON_ADD_ENABLE = "icons/icon_add_enable.png";

  static const String ICON_MINUS_DISABLE = "icons/icon_minus_disable.png";
  static const String ICON_MINUS_ENABLE = "icons/icon_minus_enable.png";

}

==> bruno-2.0.0.tar.gz: lib/src/constants/brn_asset_constants.dart <==
class BrnAsset {
  static const String emptyState = "images/empty_state.png";
  static const String stepTitle = 'images/img_step_title.png';

  static const String refreshArrowUp = "images/refresh_arrow_up.png";
  static const String refreshArrowDown = "images/refresh_arrow_down.png";
  static const String iconSelectionReset = "images/icon_selection_reset.png";
  static const String iconSingleSelected = "images/icon_single_selected.png";
  static const String iconMultiSelected = "images/icon_multi_selected.png";
  static const String iconUnSelect = "images/icon_unselect.png";
  static const String iconMore = "images/icon_more.png";
  static const String iconAlert = "icons/icon_alert.png";
  static const String iconWarning = "icons/icon_warning.png";
  static const String iconSuccess = "icons/icon_success.png";

  static const String iconStarSize = "images/icon_star_size.png";
  static const String iconStarSizeSelected =
      "images/icon_star_size_selected.png";
  static const String iconBottomPickerRightTopBg =
      "images/icon_bottom_picker_right_top_bg.png";

  static const String ICON_ARROWUP_SELECT = "images/icon_arrow_up_selected.png";
  static const String ICON_REFRESH = "assets/images/icon_refresh.png";
  static const String ICON_ARROWDOWN_SELECT =
      "images/icon_arrow_down_selected.png";
  static const String ICON_ARROWDOWN_UNSELECT =
      "images/icon_arrow_down_unselected.png";
  static const String ICON_ARROW_RIGHT_1 = "icons/icon_right_arrow_1.png";
  static const String SELECT_CHECKED_STATUS =
      "images/select_checked_status.png";
  static const String SELECT_NORMAL_STATUS = "icons/normol_border.png";
  static const String ICON_SELECTED_UP_TRIANGLE =
      "icons/icon_selcted_triangle.png";
  static const String ICON_UNSELECT_DOWN_TRIANGLE =
      "icons/icon_unselected_triangle.png";
  static const String ICON_REQUIRE_RED = 'icons/icon_require_red.png';
  static const String ICON_RIGHT_ARROW = 'icons/icon_right_arrow.png';
  static const String ICON_BACK_WHITE = 'assets/icons/icon_back_white.png';
  static const String ICON_BACK_BLACK = 'assets/icons/icon_back_black.png';
  static const String ICON_STEP_2 = 'icons/icon_step_2.png';
  static const String ICON_STEP_3 = 'icons/icon_step_3.png';
  static const String ICON_STEP_4 = 'icons/icon_step_4.png';
  static const String ICON_STEP_5 = 'icons/icon_step_5.png';
  static const String ICON_STEP_DOING = 'icons/icon_step_doing.png';
  static const String ICON_STEP_COMPLETED = 'icons/icon_step_completed.png';

  static const String ICON_DELETE_TEXT = 'icons/ic_delete_grey.png';
  static const String ICON_SEARCH = 'icons/ic_search.png';

  static const String ICON_POPUP_CLOSE = 'icons/icon_popup_close.png';
  static const String ICON_CLOSE = 'icons/icon_close.png';
  static const String ICON_CALENDAR_PRE_MONTH =
      'icons/icon_calendar_pre_month.png';
  static const String ICON_CALENDAR_NEXT_MONTH =
      'icons/icon_calendar_next_month.png';

  static const String ICON_UP_ARROW = 'icons/icon_up_arrow.png';
  static const String ICON_DOWN_ARROW = 'icons/icon_down_arrow.png';
  static const String ICON_TRASH_BIN = 'icons/icon_trash.png';
  static const String ICON_STAR_UNSELECT = 'icons/icon_star_unselect.png';
  static const String ICON_STAR_SELECT = 'icons/icon_star_select.png';
  static const String ICON_ADD_FORM_ITEM = 'icons/icon_add_form_item.png';
  static const String ICON_REMOVE_FORM_ITEM = 'icons/icon_remove_form_item.png';

  static const String ICON_TRIANGLE_DOWN = 'icons/icon_triangle_down.png';
  static const String ICON_TRIANGLE_UP = 'icons/icon_triangle_up.png';

  static const String ICON_PAIR_INFO_QUESTION =
      'icons/icon_pait_info_question.png';
  static const String ICON_PICKER_CLOSE = 'images/icon_guanbi.png';

  static const String ICON_NOTICE = 'icons/icon_notice.png';
  static const String ICON_NOTICE_ARROW_BLUE =
      'icons/icon_notice_arrow_blue.png';
  static const String ICON_NOTICE_ARROW_GREEN =
      'icons/icon_notice_arrow_green.png';
  static const String ICON_NOTICE_ARROW_ORANGE =
      'icons/icon_notice_arrow_orange.png';
  static const String ICON_NOTICE_ARROW_RED = 'icons/icon_notice_arrow_red.png';
  static const String ICON_NOTICE_CLOSE_BLUE =
      'icons/icon_notice_close_blue.png';
  static const String ICON_NOTICE_CLOSE_GREEN =
      'icons/icon_notice_close_green.png';
  static const String ICON_NOTICE_CLOSE_ORANGE =
      'icons/icon_notice_close_orange.png';
  static const String ICON_NOTICE_CLOSE_RED = 'icons/icon_notice_close_red.png';
  static const String ICON_NOTICE_FAIL = 'icons/icon_notice_fail.png';
  static const String ICON_NOTICE_RUNNING = 'icons/icon_notice_running.png';
  static const String ICON_NOTICE_SUCCEED = 'icons/icon_notice_succeed.png';
  static const String ICON_NOTICE_WARNING = 'icons/icon_notice_warning.png';

  static const String ICON_OPERATION_OTHER_RIGHT =
      'icons/icon_operation_line_right.png';
  static const String ICON_OPERATION_OTHER_LEFT =
      'icons/icon_operation_line_left.png';
  static const String ICON_RESULT_SUCCESS = 'icons/icon_result_success.png';
  static const String ICON_RESULT_ERROR = 'icons/icon_result_error.png';
  static const String ICON_STAR = 'icons/icon_star.png';
  static const String ICON_STAR_HALF = 'icons/icon_star_half.png';
  static const String ICON_UPARROW = 'icons/icon_uparrow.png';
  static const String ICOS_QRCODE_BG = 'assets/images/icon_qrcode_bg.png';
  static const String ICONS_QRCODE_FAILED =
      '/assets/images/icon_qrcode_failed.png';
  static const String ICONS_REFRESH_WHITE =
      'assets/images/icon_refresh_white.png';
  static const String ICONS_AVATAR_NEW = '/assets/icons/img_avatar_new.png';

  static const String ICON_AUDIOPALYER_PLAY = 'icons/icon_audioplayer_play.png';
  static const String ICON_AUDIOPALYER_PAUSE =
      'icons/icon_audioplayer_pause.png';

  static const String ICON_GREY_PLACE_HOLDER = 'icons/grey_place_holder.png';

  static const String ICON_QUOTATION_MARK = 'icons/ic_quotation_mark.png';

  static const String IMG_BACKGROUND_CARD = 'images/img_bg_card.png';

  static const String IMG_BG_BLUR = 'images/img_bg_blur.png';

  /// 用于图片右上角删除icon 的展示
  static const String ICON_DELETE = 'icons/icon_delete.png';

  static const String ICON_IM = 'images/icon_im_blue.png';
  static const String ICON_CALL = 'images/icon_call.png';
  static const String ICON_CALL_DISABLE = 'images/icon_call_disable.png';
  static const String PERSON_PLACE_HOLDER =
      'packages/bruno/assets/icons/img_avatar_new.png';

  /// radio组件，用于单选和多选
  static const String ICON_RADIO_MULTI_SELECTED =
      'icons/radio/multiple_selected.png';
  static const String ICON_RADIO_UNSELECTED = 'icons/radio/unselected.png';
  static const String ICON_RADIO_DISABLE_MULTI_SELECTED =
      'icons/radio/disable_multi_selected.png';
  static const String ICON_RADIO_DISABLE_UNSELECTED =
      'icons/radio/disable_unselected.png';
  static const String ICON_RADIO_SINGLE_SELECTED =
      'icons/radio/single_selected.png';
  static const String ICON_RADIO_DISABLE_SINGLE_SELECTED =
      'icons/radio/disable_single_selected.png';

  /// 评价组件--表情
  static const String ICON_APPRAISE_BAD_UNSELECTED =
      'assets/images/icon_appraise_bad_unselected.png';
  static const String ICON_APPRAISE_NOT_GOOD_UNSELECTED =
      'assets/images/icon_appraise_not_good_unselected.png';
  static const String ICON_APPRAISE_OK_UNSELECTED =
      'assets/images/icon_appraise_ok_unselected.png';
  static const String ICON_APPRAISE_GOOD_UNSELECTED =
      'assets/images/icon_appraise_good_unselected.png';
  static const String ICON_APPRAISE_SURPRISE_UNSELECTED =
      'assets/images/icon_appraise_surprise_unselected.png';

  static const String ICON_APPRAISE_BAD_DEFAULT =
      'assets/images/icon_appraise_bad_default.png';
  static const String ICON_APPRAISE_NOT_GOOD_DEFAULT =
      'assets/images/icon_appraise_not_good_default.png';
  static const String ICON_APPRAISE_OK_DEFAULT =
      'assets/images/icon_appraise_ok_default.png';
  static const String ICON_APPRAISE_GOOD_DEFAULT =
      'assets/images/icon_appraise_good_default.png';
  static const String ICON_APPRAISE_SURPRISE_DEFAULT =
      'assets/images/icon_appraise_surprise_default.png';

  static const String ICON_APPRAISE_BAD_SELECTED =
      'assets/images/icon_appraise_bad_selected.png';
  static const String ICON_APPRAISE_NOT_GOOD_SELECTED =
      'assets/images/icon_appraise_not_good_selected.png';
  static const String ICON_APPRAISE_OK_SELECTED =
      'assets/images/icon_appraise_ok_selected.png';
  static const String ICON_APPRAISE_GOOD_SELECTED =
      'assets/images/icon_appraise_good_selected.png';
  static const String ICON_APPRAISE_SURPRISE_SELECTED =
      'assets/images/icon_appraise_surprise_selected.png';
  static const String ICON_QUESTION = "icons/icon_question.png";

  /// 录入项icon
  static const String ICON_ADD_DISABLE = "icons/icon_add_disable.png";
  static const String ICON_ADD_ENABLE = "icons/icon_add_enable.png";

  static const String ICON_MINUS_DISABLE = "icons/icon_minus_disable.png";
  static const String ICON_MINUS_ENABLE = "icons/icon_minus_enable.png";
}
